@@ -27,6 +27,7 @@
 #include <QHeaderView>
 #include <QScrollBar>
 #include <QListView>
+#include <QItemDelegate>
 #include <QVBoxLayout>
 #include <QLabel>
 #include <QTreeView>
@@ -49,8 +50,27 @@
 
 namespace KDevelop {
 
+class FrameStackItemDelegate : public QItemDelegate
+{
+    Q_OBJECT
+
+public:
+    using QItemDelegate::QItemDelegate;
+
+    void paint(QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex& index) const override;
+};
+
+void FrameStackItemDelegate::paint(QPainter* painter, const QStyleOptionViewItem& option,
+                                        const QModelIndex& index) const
+{
+    QStyleOptionViewItem newOption(option);
+    newOption.textElideMode = index.column() == 2 ? Qt::ElideMiddle : Qt::ElideRight;
+
+    QItemDelegate::paint(painter, newOption, index);
+}
+
 FramestackWidget::FramestackWidget(IDebugController* controller, QWidget* parent)
-    : AutoOrientedSplitter(Qt::Horizontal, parent), m_session(0)
+    : AutoOrientedSplitter(Qt::Horizontal, parent), m_session(nullptr)
 {
     connect(controller,
             &IDebugController::currentSessionChanged,
@@ -69,41 +89,42 @@ FramestackWidget::FramestackWidget(IDebugController* controller, QWidget* parent
                       "previous calling functions."));
     setWindowIcon(QIcon::fromTheme(QStringLiteral("view-list-text"), windowIcon()));
     m_threadsWidget = new QWidget(this);
-    m_threads = new QListView(m_threadsWidget);
-    m_frames = new QTreeView(this);
-    m_frames->setRootIsDecorated(false);
-    m_frames->setSelectionMode(QAbstractItemView::ContiguousSelection);
-    m_frames->setSelectionBehavior(QAbstractItemView::SelectRows);
-    m_frames->setAllColumnsShowFocus(true);
-    m_frames->setContextMenuPolicy(Qt::CustomContextMenu);
+    m_threadsListView = new QListView(m_threadsWidget);
+    m_framesTreeView = new QTreeView(this);
+    m_framesTreeView->setRootIsDecorated(false);
+    m_framesTreeView->setItemDelegate(new FrameStackItemDelegate(this));
+    m_framesTreeView->setSelectionMode(QAbstractItemView::ContiguousSelection);
+    m_framesTreeView->setSelectionBehavior(QAbstractItemView::SelectRows);
+    m_framesTreeView->setAllColumnsShowFocus(true);
+    m_framesTreeView->setContextMenuPolicy(Qt::CustomContextMenu);
 
-    m_framesContextMenu = new QMenu(m_frames);
+    m_framesContextMenu = new QMenu(m_framesTreeView);
 
-    QAction* selectAllAction = KStandardAction::selectAll(m_frames);
+    QAction* selectAllAction = KStandardAction::selectAll(m_framesTreeView);
     selectAllAction->setShortcut(QKeySequence()); //FIXME: why does CTRL-A conflict with Katepart (while CTRL-Cbelow doesn't) ?
     selectAllAction->setShortcutContext(Qt::WidgetWithChildrenShortcut);
     connect(selectAllAction, &QAction::triggered, this, &FramestackWidget::selectAll);
     m_framesContextMenu->addAction(selectAllAction);
 
-    QAction* copyAction = KStandardAction::copy(m_frames);
+    QAction* copyAction = KStandardAction::copy(m_framesTreeView);
     copyAction->setShortcutContext(Qt::WidgetWithChildrenShortcut);
     connect(copyAction, &QAction::triggered, this, &FramestackWidget::copySelection);
     m_framesContextMenu->addAction(copyAction);
     addAction(copyAction);
 
-    connect(m_frames, &QTreeView::customContextMenuRequested, this, &FramestackWidget::frameContextMenuRequested);
+    connect(m_framesTreeView, &QTreeView::customContextMenuRequested, this, &FramestackWidget::frameContextMenuRequested);
 
     m_threadsWidget->setLayout(new QVBoxLayout());
     m_threadsWidget->layout()->addWidget(new QLabel(i18n("Threads:")));
-    m_threadsWidget->layout()->addWidget(m_threads);
+    m_threadsWidget->layout()->addWidget(m_threadsListView);
     addWidget(m_threadsWidget);
-    addWidget(m_frames);
+    addWidget(m_framesTreeView);
 
     setStretchFactor(1, 3);
-    connect(m_frames->verticalScrollBar(), &QScrollBar::valueChanged, this, &FramestackWidget::checkFetchMoreFrames);
+    connect(m_framesTreeView->verticalScrollBar(), &QScrollBar::valueChanged, this, &FramestackWidget::checkFetchMoreFrames);
 
     // Show the selected frame when clicked, even if it has previously been selected
-    connect(m_frames, &QTreeView::clicked, this, &FramestackWidget::frameSelectionChanged);
+    connect(m_framesTreeView, &QTreeView::clicked, this, &FramestackWidget::frameSelectionChanged);
 
     currentSessionChanged(controller->currentSession());
 }
@@ -116,8 +137,8 @@ void FramestackWidget::currentSessionChanged(KDevelop::IDebugSession* session)
 {
     m_session = session;
 
-    m_threads->setModel(session ? session->frameStackModel() : 0);
-    m_frames->setModel(session ? session->frameStackModel() : 0);
+    m_threadsListView->setModel(session ? session->frameStackModel() : nullptr);
+    m_framesTreeView->setModel(session ? session->frameStackModel() : nullptr);
 
     if (session) {
         connect(session->frameStackModel(), &IFrameStackModel::dataChanged,
@@ -131,11 +152,11 @@ void FramestackWidget::currentSessionChanged(KDevelop::IDebugSession* session)
         connect(session, &IDebugSession::stateChanged,
                 this, &FramestackWidget::sessionStateChanged);
 
-        connect(m_threads->selectionModel(), &QItemSelectionModel::currentChanged,
+        connect(m_threadsListView->selectionModel(), &QItemSelectionModel::currentChanged,
                 this, &FramestackWidget::setThreadShown);
 
         // Show the selected frame, independent of the means by which it has been selected
-        connect(m_frames->selectionModel(), &QItemSelectionModel::currentChanged,
+        connect(m_framesTreeView->selectionModel(), &QItemSelectionModel::currentChanged,
                 this, &FramestackWidget::frameSelectionChanged);
 
         sessionStateChanged(session->state());
@@ -151,8 +172,8 @@ void FramestackWidget::setThreadShown(const QModelIndex& current)
 
 void FramestackWidget::checkFetchMoreFrames()
 {
-    int val = m_frames->verticalScrollBar()->value();
-    int max = m_frames->verticalScrollBar()->maximum();
+    int val = m_framesTreeView->verticalScrollBar()->value();
+    int max = m_framesTreeView->verticalScrollBar()->maximum();
     const int offset = 20;
 
     if (val + offset > max && m_session) {
@@ -165,14 +186,14 @@ void FramestackWidget::currentThreadChanged(int thread)
     if (thread != -1) {
         IFrameStackModel* model = m_session->frameStackModel();
         QModelIndex idx = model->currentThreadIndex();
-        m_threads->selectionModel()->select(idx, QItemSelectionModel::ClearAndSelect | QItemSelectionModel::Rows);
+        m_threadsListView->selectionModel()->select(idx, QItemSelectionModel::ClearAndSelect | QItemSelectionModel::Rows);
         m_threadsWidget->setVisible(model->rowCount() > 1);
-        m_frames->setRootIndex(idx);
-        m_frames->header()->setSectionResizeMode(0, QHeaderView::ResizeToContents);
+        m_framesTreeView->setRootIndex(idx);
+        m_framesTreeView->header()->setSectionResizeMode(0, QHeaderView::ResizeToContents);
     } else {
         m_threadsWidget->hide();
-        m_threads->selectionModel()->clear();
-        m_frames->setRootIndex(QModelIndex());
+        m_threadsListView->selectionModel()->clear();
+        m_framesTreeView->setRootIndex(QModelIndex());
     }
 }
 
@@ -181,10 +202,10 @@ void FramestackWidget::currentFrameChanged(int frame)
     if (frame != -1) {
         IFrameStackModel* model = m_session->frameStackModel();
         QModelIndex idx = model->currentFrameIndex();
-        m_frames->selectionModel()->select(
+        m_framesTreeView->selectionModel()->select(
             idx, QItemSelectionModel::ClearAndSelect | QItemSelectionModel::Rows);
     } else {
-        m_frames->selectionModel()->clear();
+        m_framesTreeView->selectionModel()->clear();
     }
 }
 
@@ -204,13 +225,13 @@ void FramestackWidget::frameSelectionChanged(const QModelIndex& current /* previ
 
 void FramestackWidget::frameContextMenuRequested(const QPoint& pos)
 {
-    m_framesContextMenu->popup( m_frames->mapToGlobal(pos) + QPoint(0, m_frames->header()->height()) );
+    m_framesContextMenu->popup( m_framesTreeView->mapToGlobal(pos) + QPoint(0, m_framesTreeView->header()->height()) );
 }
 
 void FramestackWidget::copySelection()
 {
     QClipboard *cb = QApplication::clipboard();
-    QModelIndexList indexes = m_frames->selectionModel()->selectedRows();
+    QModelIndexList indexes = m_framesTreeView->selectionModel()->selectedRows();
     QString content;
     Q_FOREACH(const QModelIndex& index, indexes) {
         IFrameStackModel::FrameItem frame = m_session->frameStackModel()->frame(index);
@@ -227,15 +248,15 @@ void FramestackWidget::copySelection()
 
 void FramestackWidget::selectAll()
 {
-    m_frames->selectAll();
+    m_framesTreeView->selectAll();
 }
 
 void FramestackWidget::sessionStateChanged(KDevelop::IDebugSession::DebuggerState state)
 {
     bool enable = state == IDebugSession::PausedState || state == IDebugSession::StoppedState;
-    m_frames->setEnabled(enable);
-    m_threads->setEnabled(enable);
+    setEnabled(enable);
 }
 
 }
 
+#include "framestackwidget.moc"
