@@ -31,7 +31,7 @@ using namespace KDevelop;
 
 TreeModel::TreeModel(const QVector<QString>& headers,
                      QObject *parent)
-  : QAbstractItemModel(parent), headers_(headers), root_(NULL)
+  : QAbstractItemModel(parent), headers_(headers), root_(nullptr)
 {
 }
 
@@ -58,13 +58,16 @@ QVariant TreeModel::data(const QModelIndex &index, int role) const
         return QVariant();
 
     TreeItem *item = static_cast<TreeItem*>(index.internalPointer());
+    if (role == ItemRole)
+        return QVariant::fromValue(item);
+
     return item->data(index.column(), role);
 }
 
 Qt::ItemFlags TreeModel::flags(const QModelIndex &index) const
 {
     if (!index.isValid())
-        return 0;
+        return nullptr;
 
     return Qt::ItemIsEnabled | Qt::ItemIsSelectable;
 }
@@ -139,7 +142,7 @@ TreeItem* TreeModel::itemForIndex(const QModelIndex& index) const
 
 QModelIndex TreeModel::indexForItem(TreeItem *item, int column) const
 {
-    if (item->parent() == 0)
+    if (item->parent() == nullptr)
         return QModelIndex();
 
     if (TreeItem* parent = item->parent())
