@@ -47,6 +47,7 @@
 #include <project/projectmodel.h>
 
 #include <util/path.h>
+#include <util/shellutils.h>
 
 namespace KDevelop {
 
@@ -206,6 +207,16 @@ DocumentChangeSet::ChangeResult DocumentChangeSet::applyAllChanges()
         oldActiveDoc = activeDoc->url();
     }
 
+    QList<QUrl> allFiles;
+    foreach (IndexedString file, d->documentsRename.keys().toSet() + d->changes.keys().toSet()) {
+        allFiles << file.toUrl();
+    }
+
+    if (!KDevelop::ensureWritable(allFiles))
+    {
+        return ChangeResult(QStringLiteral("some affected files are not writable"));
+    }
+
     // rename files
     QHash<IndexedString, IndexedString>::const_iterator it = d->documentsRename.constBegin();
     for(; it != d->documentsRename.constEnd(); ++it) {
@@ -364,7 +375,7 @@ DocumentChangeSet::ChangeResult DocumentChangeSetPrivate::generateNewText(const
                                                                           QString & output)
 {
 
-    ISourceFormatter* formatter = 0;
+    ISourceFormatter* formatter = nullptr;
     if(ICore::self()) {
         formatter = ICore::self()->sourceFormatterController()->formatterForUrl(file.toUrl());
     }
