@@ -19,10 +19,10 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#ifndef ICONTEXTBROWSER_H
-#define ICONTEXTBROWSER_H
+#ifndef KDEVPLATFORM_ICONTEXTBROWSER_H
+#define KDEVPLATFORM_ICONTEXTBROWSER_H
 
-#include "../languageexport.h"
+#include <language/languageexport.h>
 
 #include <language/duchain/duchainpointer.h>
 
@@ -48,4 +48,4 @@ public:
 
 Q_DECLARE_INTERFACE( KDevelop::IContextBrowser, "org.kdevelop.IContextBrowser" )
 
-#endif // ICONTEXTBROWSER_H
+#endif // KDEVPLATFORM_ICONTEXTBROWSER_H
