@@ -28,8 +28,8 @@
 namespace Utils {
 /**
  * Use this class to conveniently iterate over the items in a set.
- * @param T The type the indices will be converted to
- * @param Conversion Should be a class that has a toIndex member function that takes an object of type T as parameter, and returns an index,
+ * @tparam T The type the indices will be converted to
+ * @tparam Conversion Should be a class that has a toIndex member function that takes an object of type T as parameter, and returns an index,
  *                   and a toItem member function that takes an index, and returns an item of type T.
  * */
 template<class T, class Conversion>
@@ -108,14 +108,14 @@ class VirtualSetNode {
             if(m_data->leftNode())
                 return StaticRepository::repository()->nodeFromIndex(m_data->leftNode());
             else
-                return 0;
+                return nullptr;
         }
 
         inline VirtualSetNode<T, Conversion, StaticRepository> rightChild() const {
             if(m_data->rightNode())
                 return StaticRepository::repository()->nodeFromIndex(m_data->rightNode());
             else
-                return 0;
+                return nullptr;
         }
 
         ///Returns the start of this node's range. If this is a final node, the length of the range is 1.
@@ -344,8 +344,8 @@ uint qHash(const StorableSet<T, Conversion, StaticRepository, doReferenceCountin
      *
      * @todo eventually make this unnecessary
      *
-     * @param T Should be the type that should be dealt
-     * @param Conversion Should be a class that has a toIndex member function that takes an object of type T as parameter, and returns an index,
+     * @tparam T Should be the type that should be dealt
+     * @tparam Conversion Should be a class that has a toIndex member function that takes an object of type T as parameter, and returns an index,
      *                   and a toItem member function that takes an index, and returns an item of type T.
      **/
 template<class T, class Conversion>
@@ -468,8 +468,8 @@ class LazySet : public Conversion {
   ///Persistent repository that manages string-sets, also correctly increasing the string reference-counts as needed
   struct KDEVPLATFORMLANGUAGE_EXPORT StringSetRepository : public Utils::BasicSetRepository {
     StringSetRepository(QString name);
-    virtual void itemRemovedFromSets(uint index) override;
-    virtual void itemAddedToSets(uint index) override;
+    void itemRemovedFromSets(uint index) override;
+    void itemAddedToSets(uint index) override;
   };
   
 }
