@@ -54,11 +54,11 @@ static const QString interpreterForUrl(const QUrl& url) {
     auto mimetype = QMimeDatabase().mimeTypeForUrl(url);
     static QHash<QString, QString> knownMimetypes;
     if ( knownMimetypes.isEmpty() ) {
-        knownMimetypes["text/x-python"] = "python";
-        knownMimetypes["application/x-php"] = "php";
-        knownMimetypes["application/x-ruby"] = "ruby";
-        knownMimetypes["application/x-shellscript"] = "bash";
-        knownMimetypes["application/x-perl"] = "perl -e";
+        knownMimetypes[QStringLiteral("text/x-python")] = QStringLiteral("python3");
+        knownMimetypes[QStringLiteral("application/x-php")] = QStringLiteral("php");
+        knownMimetypes[QStringLiteral("application/x-ruby")] = QStringLiteral("ruby");
+        knownMimetypes[QStringLiteral("application/x-shellscript")] = QStringLiteral("bash");
+        knownMimetypes[QStringLiteral("application/x-perl")] = QStringLiteral("perl -e");
     }
     const QString& interp = knownMimetypes.value(mimetype.name());
     return interp;
@@ -66,12 +66,12 @@ static const QString interpreterForUrl(const QUrl& url) {
 
 QIcon ScriptAppConfigPage::icon() const
 {
-    return QIcon::fromTheme("system-run");
+    return QIcon::fromTheme(QStringLiteral("system-run"));
 }
 
 void ScriptAppConfigPage::loadFromConfiguration(const KConfigGroup& cfg, KDevelop::IProject* project )
 {
-    bool b = blockSignals( true );
+    QSignalBlocker blocker(this);
     if( project )
     {
         executablePath->setStartDir( project->path().toUrl() );
@@ -79,7 +79,7 @@ void ScriptAppConfigPage::loadFromConfiguration(const KConfigGroup& cfg, KDevelo
 
     auto doc = KDevelop::ICore::self()->documentController()->activeDocument();
     interpreter->lineEdit()->setText( cfg.readEntry( ExecuteScriptPlugin::interpreterEntry,
-                                                     doc ? interpreterForUrl(doc->url()) : "" ) );
+                                                     doc ? interpreterForUrl(doc->url()) : QString() ) );
     executablePath->setUrl( QUrl::fromLocalFile(cfg.readEntry( ExecuteScriptPlugin::executableEntry, QString() )) );
     remoteHostCheckbox->setChecked( cfg.readEntry( ExecuteScriptPlugin::executeOnRemoteHostEntry, false ) );
     remoteHost->setText( cfg.readEntry( ExecuteScriptPlugin::remoteHostEntry, "" ) );
@@ -94,7 +94,6 @@ void ScriptAppConfigPage::loadFromConfiguration(const KConfigGroup& cfg, KDevelo
     environment->setCurrentProfile( cfg.readEntry( ExecuteScriptPlugin::environmentGroupEntry, QString() ) );
     outputFilteringMode->setCurrentIndex( cfg.readEntry( ExecuteScriptPlugin::outputFilteringEntry, 2u ));
     //runInTerminal->setChecked( cfg.readEntry( ExecuteScriptPlugin::useTerminalEntry, false ) );
-    blockSignals( b );
 }
 
 ScriptAppConfigPage::ScriptAppConfigPage( QWidget* parent )
@@ -149,7 +148,7 @@ QString ScriptAppLauncher::description() const
 
 QString ScriptAppLauncher::id()
 {
-    return "scriptAppLauncher";
+    return QStringLiteral("scriptAppLauncher");
 }
 
 QString ScriptAppLauncher::name() const
@@ -167,19 +166,19 @@ KJob* ScriptAppLauncher::start(const QString& launchMode, KDevelop::ILaunchConfi
     Q_ASSERT(cfg);
     if( !cfg )
     {
-        return 0;
+        return nullptr;
     }
-    if( launchMode == "execute" )
+    if( launchMode == QLatin1String("execute") )
     {
         return new ScriptAppJob( m_plugin, cfg);
     }
     qWarning() << "Unknown launch mode " << launchMode << "for config:" << cfg->name();
-    return 0;
+    return nullptr;
 }
 
 QStringList ScriptAppLauncher::supportedModes() const
 {
-    return QStringList() << "execute";
+    return QStringList() << QStringLiteral("execute");
 }
 
 KDevelop::LaunchConfigurationPage* ScriptAppPageFactory::createWidget(QWidget* parent)
@@ -220,7 +219,7 @@ QString ScriptAppConfigType::id() const
 
 QIcon ScriptAppConfigType::icon() const
 {
-    return QIcon::fromTheme("preferences-plugin-script");
+    return QIcon::fromTheme(QStringLiteral("preferences-plugin-script"));
 }
 
 bool ScriptAppConfigType::canLaunch(const QUrl& file) const
