@@ -40,7 +40,7 @@ using namespace KDevelop;
 TemplatePreviewToolView::TemplatePreviewToolView(FileTemplatesPlugin* plugin, QWidget* parent, Qt::WindowFlags f)
 : QWidget(parent, f)
 , ui(new Ui::TemplatePreviewToolView)
-, m_original(0)
+, m_original(nullptr)
 , m_plugin(plugin)
 {
     ui->setupUi(this);
@@ -77,10 +77,6 @@ TemplatePreviewToolView::~TemplatePreviewToolView()
 
 void TemplatePreviewToolView::documentActivated(KDevelop::IDocument* document)
 {
-    if (!isVisible()) {
-        return;
-    }
-
     documentChanged(document->textDocument());
 }
 
@@ -131,17 +127,15 @@ void TemplatePreviewToolView::documentChanged(KTextEditor::Document* document)
 void TemplatePreviewToolView::showEvent(QShowEvent*)
 {
     IDocument* doc = ICore::self()->documentController()->activeDocument();
-    documentChanged(doc ? doc->textDocument() : 0);
+    documentChanged(doc ? doc->textDocument() : nullptr);
 }
 
 void TemplatePreviewToolView::documentClosed(IDocument* document)
 {
-    if (!isVisible()) {
-        return;
-    }
+    m_original = nullptr;
 
     if (document && document->textDocument() == m_original) {
-        documentChanged(0);
+        documentChanged(nullptr);
     }
 }
 
