@@ -89,9 +89,8 @@ bool canOpenDefault(const QString& mimeType)
 
 OpenWithPlugin::OpenWithPlugin ( QObject* parent, const QVariantList& )
     : IPlugin ( QStringLiteral("kdevopenwith"), parent ),
-    m_actionMap( 0 )
+    m_actionMap( nullptr )
 {
-    KDEV_USE_EXTENSION_INTERFACE( IOpenWith )
 }
 
 OpenWithPlugin::~OpenWithPlugin()
@@ -148,7 +147,7 @@ KDevelop::ContextMenuExtension OpenWithPlugin::contextMenuExtension( KDevelop::C
     }
 
     {
-        auto other = new QAction(i18n("other..."), this);
+        auto other = new QAction(i18n("Other..."), this);
         connect(other, &QAction::triggered, this, [this] {
             auto dialog = new KOpenWithDialog(m_urls, ICore::self()->uiController()->activeMainWindow());
             if (dialog->exec() == QDialog::Accepted && dialog->service()) {
@@ -192,7 +191,7 @@ QList<QAction*> OpenWithPlugin::actionsForServiceType( const QString& serviceTyp
 
     m_services += list;
     QList<QAction*> actions;
-    QAction* standardAction = 0;
+    QAction* standardAction = nullptr;
     const QString defaultId = defaultForMimeType(m_mimeType);
     foreach( KService::Ptr svc, list ) {
         QAction* act = new QAction( isTextEditor(svc) ? i18n("Default Editor") : svc->name(), this );
