@@ -67,7 +67,7 @@ KDevelop::VcsJob::JobStatus SvnJobBase::status() const
 void SvnJobBase::askForLogin( const QString& realm )
 {
     qCDebug(PLUGIN_SVN) << "login";
-    KPasswordDialog dlg( 0, KPasswordDialog::ShowUsernameLine | KPasswordDialog::ShowKeepPassword );
+    KPasswordDialog dlg( nullptr, KPasswordDialog::ShowUsernameLine | KPasswordDialog::ShowKeepPassword );
     dlg.setPrompt( i18n("Enter Login for: %1", realm ) );
     dlg.exec();
     internalJob()->m_login_username = dlg.username();
@@ -117,7 +117,7 @@ void SvnJobBase::askForSslServerTrust( const QStringList& failures, const QStrin
 
 void SvnJobBase::askForSslClientCert( const QString& realm )
 {
-    KMessageBox::information( 0, realm );
+    KMessageBox::information( nullptr, realm );
     qCDebug(PLUGIN_SVN) << "clientrust";
     internalJob()->m_guiSemaphore.release( 1 );
 }
@@ -130,13 +130,13 @@ void SvnJobBase::askForSslClientCertPassword( const QString& )
 
 void SvnJobBase::internalJobStarted()
 {
-    qDebug() << "job started" << static_cast<void*>(internalJob());
+    qCDebug(PLUGIN_SVN)  << "job started" << static_cast<void*>(internalJob());
     m_status = KDevelop::VcsJob::JobRunning;
 }
 
 void SvnJobBase::internalJobDone()
 {
-    qDebug() << "job done" << internalJob();
+    qCDebug(PLUGIN_SVN) << "job done" << internalJob();
     if ( m_status == VcsJob::JobFailed ) {
         // see: https://bugs.kde.org/show_bug.cgi?id=273759
         // this gets also called when the internal job failed
@@ -163,7 +163,7 @@ void SvnJobBase::internalJobDone()
 
 void SvnJobBase::internalJobFailed()
 {
-    qDebug() << "job failed" << internalJob();
+    qCDebug(PLUGIN_SVN) << "job failed" << internalJob();
 
     setError( 255 );
     QString msg = internalJob()->errorMessage();
