@@ -151,7 +151,7 @@ QVariant ProblemModel::data(const QModelIndex& index, int role) const
         case Error:
             return p->description();
         case File:
-            return displayUrl(p->finalLocation().document.toUrl(), baseDirectory);
+            return displayUrl(p->finalLocation().document.toUrl().adjusted(QUrl::NormalizePathSegments), baseDirectory);
         case Line:
             if (p->finalLocation().isValid()) {
                 return QString::number(p->finalLocation().start().line() + 1);
@@ -236,7 +236,7 @@ void ProblemModel::setFeatures(Features features)
 void ProblemModel::addProblem(const IProblem::Ptr &problem)
 {
     int c = d->m_problems->count();
-    beginInsertRows(QModelIndex(), c, c + 1);
+    beginInsertRows(QModelIndex(), c, c);
     d->m_problems->addProblem(problem);
     endInsertRows();
 }
