@@ -124,16 +124,17 @@ SourceFormatterController::SourceFormatterController(QObject *parent)
     m_formatFilesAction->setWhatsThis(i18n("Formatting functionality using <b>astyle</b> library."));
     connect(m_formatFilesAction, &QAction::triggered, this, static_cast<void(SourceFormatterController::*)()>(&SourceFormatterController::formatFiles));
 
-    m_formatTextAction->setEnabled(false);
-    m_formatFilesAction->setEnabled(true);
-
+    // connect to both documentActivated & documentClosed,
+    // otherwise we miss when the last document was closed
     connect(Core::self()->documentController(), &IDocumentController::documentActivated,
-            this, &SourceFormatterController::activeDocumentChanged);
+            this, &SourceFormatterController::updateFormatTextAction);
+    connect(Core::self()->documentController(), &IDocumentController::documentClosed,
+            this, &SourceFormatterController::updateFormatTextAction);
     // Use a queued connection, because otherwise the view is not yet fully set up
     connect(Core::self()->documentController(), &IDocumentController::documentLoaded,
             this, &SourceFormatterController::documentLoaded, Qt::QueuedConnection);
 
-    activeDocumentChanged(Core::self()->documentController()->activeDocument());
+    updateFormatTextAction();
 }
 
 void SourceFormatterController::documentLoaded( IDocument* doc )
@@ -339,23 +340,26 @@ void SourceFormatterController::cleanup()
 {
 }
 
-
-void SourceFormatterController::activeDocumentChanged(IDocument* doc)
+void SourceFormatterController::updateFormatTextAction()
 {
     bool enabled = false;
 
+    IDocument* doc = KDevelop::ICore::self()->documentController()->activeDocument();
     if (doc) {
         QMimeType mime = QMimeDatabase().mimeTypeForUrl(doc->url());
         if (isMimeTypeSupported(mime))
             enabled = true;
     }
 
+    m_formatLine->setEnabled(enabled);
     m_formatTextAction->setEnabled(enabled);
 }
 
 void SourceFormatterController::beautifySource()
 {
     IDocument* idoc = KDevelop::ICore::self()->documentController()->activeDocument();
+    if (!idoc)
+        return;
     KTextEditor::View* view = idoc->activeTextView();
     if (!view)
         return;
@@ -432,6 +436,11 @@ void SourceFormatterController::beautifyLine()
 
 void SourceFormatterController::formatDocument(KDevelop::IDocument* doc, ISourceFormatter* formatter, const QMimeType& mime)
 {
+    Q_ASSERT(doc);
+    Q_ASSERT(formatter);
+
+    qCDebug(SHELL) << "Running" << formatter->name() << "on" << doc->url();
+
     // We don't use KTextEditor::Document directly, because CodeRepresentation transparently works
     // around a possible tab-replacement incompatibility between kate and kdevelop
     CodeRepresentation::Ptr code = KDevelop::createCodeRepresentation( IndexedString( doc->url() ) );
@@ -576,10 +585,10 @@ void SourceFormatterController::formatFiles(QList<QUrl> &list)
         qCDebug(SHELL) << "Processing file " << list[fileCount] << endl;
         KIO::StoredTransferJob *job = KIO::storedGet(list[fileCount]);
         if (job->exec()) {
-            QByteArray data = job->data();
-            QString output = formatter->formatSource(data, list[fileCount], mime);
-            data += addModelineForCurrentLang(output, list[fileCount], mime).toUtf8();
-            job = KIO::storedPut(data, list[fileCount], -1);
+            QString text = QString::fromLocal8Bit(job->data());
+            text = formatter->formatSource(text, list[fileCount], mime);
+            text = addModelineForCurrentLang(text, list[fileCount], mime).toUtf8();
+            job = KIO::storedPut(text.toLocal8Bit(), list[fileCount], -1, KIO::Overwrite);
             if (!job->exec())
                 KMessageBox::error(nullptr, job->errorString());
         } else
