@@ -33,6 +33,7 @@
 #include "view.h"
 #include "controller.h"
 #include "container.h"
+#include "idealbuttonbarwidget.h"
 #include "idealcontroller.h"
 #include "holdupdates.h"
 #include "sublimedebug.h"
@@ -42,7 +43,7 @@ Q_LOGGING_CATEGORY(SUBLIME, "kdevplatform.sublime")
 namespace Sublime {
 
 MainWindow::MainWindow(Controller *controller, Qt::WindowFlags flags)
-: KParts::MainWindow(0, flags), d(new MainWindowPrivate(this, controller))
+: KParts::MainWindow(nullptr, flags), d(new MainWindowPrivate(this, controller))
 {
     connect(this, &MainWindow::destroyed, controller, static_cast<void(Controller::*)()>(&Controller::areaReleased));
 
@@ -107,7 +108,7 @@ QList<Container*> MainWindow::containers() const
 void MainWindow::setArea(Area *area)
 {
     if (d->area)
-        disconnect(d->area, 0, d, 0);
+        disconnect(d->area, nullptr, d, nullptr);
 
     bool differentArea = (area != d->area);
     /* All views will be removed from dock area now.  However, this does
@@ -235,6 +236,10 @@ void MainWindow::saveSettings()
         }
     }
 
+    d->idealController->leftBarWidget->saveOrderSettings(cg);
+    d->idealController->bottomBarWidget->saveOrderSettings(cg);
+    d->idealController->rightBarWidget->saveOrderSettings(cg);
+
     cg.sync();
 }
 
@@ -323,6 +328,10 @@ void MainWindow::loadSettings()
 
     hu.stop();
 
+    d->idealController->leftBarWidget->loadOrderSettings(cg);
+    d->idealController->bottomBarWidget->loadOrderSettings(cg);
+    d->idealController->rightBarWidget->loadOrderSettings(cg);
+
     emit settingsLoaded();
 
     d->disableConcentrationMode();
@@ -419,7 +428,7 @@ View* MainWindow::viewForPosition(QPoint globalPos) const
        }
     }
 
-    return 0;
+    return nullptr;
 }
 
 void MainWindow::setBackgroundCentralWidget(QWidget* w)
